pub struct SimpleBalancerController {
bounds: BalancerControllerBounds,
}Expand description
Controller that uses the simple linear formula limit * min(current / setpoint, 1.0) to
compute the control output.
Fields
bounds: BalancerControllerBoundsTrait Implementations
Sourceimpl Clone for SimpleBalancerController
impl Clone for SimpleBalancerController
Sourcefn clone(&self) -> SimpleBalancerController
fn clone(&self) -> SimpleBalancerController
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SimpleBalancerController
impl Debug for SimpleBalancerController
Sourceimpl Default for SimpleBalancerController
impl Default for SimpleBalancerController
Sourcefn default() -> SimpleBalancerController
fn default() -> SimpleBalancerController
Returns the “default value” for a type. Read more
Sourceimpl SurbBalancerController for SimpleBalancerController
impl SurbBalancerController for SimpleBalancerController
Sourcefn bounds(&self) -> BalancerControllerBounds
fn bounds(&self) -> BalancerControllerBounds
Gets the current bounds of the controller.
Sourcefn set_target_and_limit(&mut self, bounds: BalancerControllerBounds)
fn set_target_and_limit(&mut self, bounds: BalancerControllerBounds)
Updates the controller’s target (setpoint) and output limit.
Sourcefn next_control_output(&mut self, current_buffer_level: u64) -> u64
fn next_control_output(&mut self, current_buffer_level: u64) -> u64
Queries the controller for the next control output based on the
current_buffer_level of SURBs.Auto Trait Implementations
impl Freeze for SimpleBalancerController
impl RefUnwindSafe for SimpleBalancerController
impl Send for SimpleBalancerController
impl Sync for SimpleBalancerController
impl Unpin for SimpleBalancerController
impl UnwindSafe for SimpleBalancerController